@@ -42,38 +42,38 @@ get_dra <- function(state, year = 2020, geometry = TRUE, clean_names = TRUE, eps
   tb <- readr::read_csv(
     file = paste0(base_path, end_path), col_types = spec,
     show_col_types = FALSE
-  ) %>%
+  ) |>
     dplyr::rename_with(.fn = \(x) stringr::str_remove_all(x, pattern = '\\d+'), .cols = dplyr::starts_with('GEOID'))
 
   if (geometry) {
     if ((year == 2020 && !state %in% block_group_states_2020 && state != 'ME') ||
       (year == 2010 && !state %in% block_group_states_2010)) {
       # regular vtds
-      geo <- tinytiger::tt_voting_districts(state = state, year = year) %>%
-        dplyr::select(dplyr::any_of(c(GEOID = 'GEOID10', GEOID = 'GEOID20')), 'geometry') %>%
+      geo <- tinytiger::tt_voting_districts(state = state, year = year) |>
+        dplyr::select(dplyr::any_of(c(GEOID = 'GEOID10', GEOID = 'GEOID20')), 'geometry') |>
         dplyr::mutate(dplyr::across('GEOID', as.character))
     } else {
       if (year == 2020 && state == 'ME') {
         # frankenstein's vtds
-        geo_a <- tinytiger::tt_voting_districts(state = state, year = year) %>%
-          dplyr::select(dplyr::any_of(c(GEOID = 'GEOID20', county = 'COUNTYFP20')), 'geometry') %>%
+        geo_a <- tinytiger::tt_voting_districts(state = state, year = year) |>
+          dplyr::select(dplyr::any_of(c(GEOID = 'GEOID20', county = 'COUNTYFP20')), 'geometry') |>
           dplyr::mutate(dplyr::across('GEOID', as.character))
-        geo_b <- tinytiger::tt_county_subdivisions(state = state, year = year) %>%
-          dplyr::select(dplyr::any_of(c('GEOID', county = 'COUNTYFP')), 'geometry') %>%
+        geo_b <- tinytiger::tt_county_subdivisions(state = state, year = year) |>
+          dplyr::select(dplyr::any_of(c('GEOID', county = 'COUNTYFP')), 'geometry') |>
           dplyr::mutate(dplyr::across('GEOID', as.character))
         geo <- dplyr::bind_rows(
-          geo_a, geo_b %>% dplyr::filter(!.data$county %in% geo_a$county)
+          geo_a, geo_b |> dplyr::filter(!.data$county %in% geo_a$county)
         )
       } else {
         # block groups
-        geo <- tinytiger::tt_block_groups(state = state, year = year) %>%
-          dplyr::select(dplyr::any_of(c(GEOID = 'GEOID10', GEOID = 'GEOID20')), 'geometry') %>%
+        geo <- tinytiger::tt_block_groups(state = state, year = year) |>
+          dplyr::select(dplyr::any_of(c(GEOID = 'GEOID10', GEOID = 'GEOID20')), 'geometry') |>
           dplyr::mutate(dplyr::across('GEOID', as.character))
       }
     }
-    tb <- tb %>%
-      dplyr::left_join(geo, by = 'GEOID') %>%
-      dplyr::relocate('GEOID', .before = dplyr::everything()) %>%
+    tb <- tb |>
+      dplyr::left_join(geo, by = 'GEOID') |>
+      dplyr::relocate('GEOID', .before = dplyr::everything()) |>
       sf::st_as_sf()
 
     tb <- make_planar_pair(tb, epsg = epsg)$x
@@ -162,5 +162,5 @@ dra_office <- tibble::tribble(
   'ltg', 'ltg',
   'pres', 'pre',
   'sen', 'uss'
-) %>%
+) |>
   tibble::deframe()
