@@ -7,6 +7,6 @@ data('nrcsd')
 data('orange')
 
 o_and_r <- rbind(orange, rockland)
-o_and_r <- o_and_r %>%
-  geo_filter(nrcsd) %>%
+o_and_r <- o_and_r |>
+  geo_filter(nrcsd) |>
   geo_trim(nrcsd)
