@@ -1,6 +1,6 @@
-test_that("geo_filter works", {
+test_that('geo_filter works', {
   nr <- geo_filter(rockland, nrcsd)
-  
+
   expect_equal(nrow(nr), 722)
 })
 
@@ -9,4 +9,4 @@ test_that('geo_trim works', {
   nr <- geo_filter(rockland, nrcsd)
   nr <- geo_trim(nr, nrcsd)
   expect_equal(nrow(nr), 689)
-})
\ No newline at end of file
+})
